@@ -29,13 +29,19 @@
 
 #include "neon/types.h"
 
+#include "neon/aba.h"
 #include "neon/abd.h"
+#include "neon/abdl.h"
 #include "neon/abs.h"
 #include "neon/add.h"
 #include "neon/addl.h"
+#include "neon/addlv.h"
 #include "neon/addl_high.h"
+#include "neon/addv.h"
 #include "neon/addw.h"
+#include "neon/addw_high.h"
 #include "neon/and.h"
+#include "neon/bic.h"
 #include "neon/bsl.h"
 #include "neon/cagt.h"
 #include "neon/ceq.h"
@@ -46,43 +52,63 @@
 #include "neon/cgtz.h"
 #include "neon/cle.h"
 #include "neon/clez.h"
+#include "neon/cls.h"
 #include "neon/clt.h"
 #include "neon/cltz.h"
+#include "neon/clz.h"
+#include "neon/cnt.h"
 #include "neon/cvt.h"
 #include "neon/combine.h"
 #include "neon/create.h"
 #include "neon/dot.h"
 #include "neon/dot_lane.h"
+#include "neon/dup_lane.h"
 #include "neon/dup_n.h"
 #include "neon/eor.h"
 #include "neon/ext.h"
 #include "neon/get_high.h"
 #include "neon/get_lane.h"
 #include "neon/get_low.h"
+#include "neon/hadd.h"
+#include "neon/hsub.h"
 #include "neon/ld1.h"
 #include "neon/ld3.h"
 #include "neon/ld4.h"
 #include "neon/max.h"
+#include "neon/maxnm.h"
+#include "neon/maxv.h"
 #include "neon/min.h"
+#include "neon/minnm.h"
+#include "neon/minv.h"
 #include "neon/mla.h"
 #include "neon/mla_n.h"
 #include "neon/mlal.h"
 #include "neon/mlal_high.h"
+#include "neon/mlal_n.h"
+#include "neon/mls.h"
+#include "neon/mlsl.h"
+#include "neon/mlsl_high.h"
+#include "neon/mlsl_n.h"
 #include "neon/movl.h"
 #include "neon/movl_high.h"
 #include "neon/movn.h"
+#include "neon/movn_high.h"
 #include "neon/mul.h"
+#include "neon/mul_lane.h"
 #include "neon/mul_n.h"
 #include "neon/mull.h"
+#include "neon/mull_high.h"
 #include "neon/mull_n.h"
 #include "neon/mvn.h"
 #include "neon/neg.h"
+#include "neon/orn.h"
 #include "neon/orr.h"
 #include "neon/padal.h"
 #include "neon/padd.h"
 #include "neon/paddl.h"
 #include "neon/pmax.h"
 #include "neon/pmin.h"
+#include "neon/qabs.h"
 #include "neon/qadd.h"
 #include "neon/qdmulh.h"
 #include "neon/qdmull.h"
@@ -91,6 +117,9 @@
 #include "neon/qmovn.h"
 #include "neon/qmovun.h"
 #include "neon/qmovn_high.h"
+#include "neon/qneg.h"
+#include "neon/qsub.h"
+#include "neon/qshl.h"
 #include "neon/qtbl.h"
 #include "neon/qtbx.h"
 #include "neon/rbit.h"
@@ -99,6 +128,7 @@
 #include "neon/rev32.h"
 #include "neon/rev64.h"
 #include "neon/rhadd.h"
+#include "neon/rnd.h"
 #include "neon/rshl.h"
 #include "neon/rshr_n.h"
 #include "neon/rsra_n.h"
@@ -113,12 +143,15 @@
 #include "neon/st4.h"
 #include "neon/sub.h"
 #include "neon/subl.h"
+#include "neon/subw.h"
+#include "neon/subw_high.h"
 #include "neon/tbl.h"
 #include "neon/tbx.h"
 #include "neon/trn.h"
 #include "neon/trn1.h"
 #include "neon/trn2.h"
 #include "neon/tst.h"
+#include "neon/uqadd.h"
 #include "neon/uzp.h"
 #include "neon/uzp1.h"
 #include "neon/uzp2.h"
