@@ -8,10 +8,6 @@ SIMDE_TEST_DECLARE_SUITE(sse4_2)
 SIMDE_TEST_DECLARE_SUITE(avx)
 SIMDE_TEST_DECLARE_SUITE(avx2)
 SIMDE_TEST_DECLARE_SUITE(fma)
-SIMDE_TEST_DECLARE_SUITE(avx512f)
-SIMDE_TEST_DECLARE_SUITE(avx512bw)
-SIMDE_TEST_DECLARE_SUITE(avx512vl)
-SIMDE_TEST_DECLARE_SUITE(avx512dq)
-SIMDE_TEST_DECLARE_SUITE(avx512cd)
 SIMDE_TEST_DECLARE_SUITE(gfni)
+SIMDE_TEST_DECLARE_SUITE(clmul)
 SIMDE_TEST_DECLARE_SUITE(svml)
